Skip to contents

Get a list with the names of the variables pass as parameter

Usage

get_list(name_var = NULL)

Arguments

name_var

A list of variable you want to pass a name for a list

Value

a list of zero named after the variable in name_var parameter

Examples

vec <- get_list(name_var = c("var1", "var2"))