R/cramer_tab.R
get_list.Rd
Get a list with the names of the variables pass as parameter
get_list(name_var = NULL)
A list of variable you want to pass a name for a list
a list of zero named after the variable in name_var parameter
vec <- get_list(name_var = c("var1", "var2"))